@@ -1,4 +1,8 @@
-#![allow(clippy::needless_pass_by_value, clippy::if_not_else)]
+#![allow(
+    clippy::blocks_in_conditions,
+    clippy::needless_pass_by_value,
+    clippy::if_not_else
+)]
 
 extern crate proc_macro;
 
@@ -352,6 +356,14 @@ fn expand_function_body(function: Function) -> TokenStream2 {
         }
     }
 
+    // Apply a macro-generated span to the "unsafe" token for the unsafe block.
+    // This is instead of reusing the caller's function signature's #unsafety
+    // across both the generated function signature and generated unsafe block,
+    // and instead of using `semi_token.span` like for the rest of the generated
+    // code below, both of which would cause `forbid(unsafe_code)` located in
+    // the caller to reject the expanded code.
+    let macro_generated_unsafe = quote!(unsafe);
+
     quote_spanned! {semi_token.span=>
         #(#attrs)*
         #inline_attr
@@ -366,7 +378,8 @@ fn expand_function_body(function: Function) -> TokenStream2 {
             let _ = ::ref_cast::__private::CurrentCrate::<#from_type, #to_type> {};
 
             #allow_unused_unsafe // in case they are building with deny(unsafe_op_in_unsafe_fn)
-            unsafe {
+            #[allow(clippy::transmute_ptr_to_ptr)]
+            #macro_generated_unsafe {
                 ::ref_cast::__private::transmute::<#from_type, #to_type>(#arg)
             }
         }
